@@ -1,7 +1,9 @@
-#' Return ids of parameters in parameter set.
+#' @title Return ids of parameters in parameter set.
 #'
+#' @description
 #' Useful if vectors are included.
-#' @template arg_parset
+#'
+#' @template arg_par_or_set
 #' @param repeated [\code{logical(1)}]\cr
 #'   Should ids be repeated length-times if parameter is a vector?
 #'   Default is \code{FALSE}.
@@ -19,27 +21,29 @@
 #' getParamIds(ps)
 #' getParamIds(ps, repeated = TRUE)
 #' getParamIds(ps, repeated = TRUE, with.nr = TRUE)
-getParamIds = function(par.set, repeated = FALSE, with.nr = FALSE) {
-  assertClass(par.set, "ParamSet")
+getParamIds = function(par, repeated = FALSE, with.nr = FALSE) {
   assertFlag(repeated)
   assertFlag(with.nr)
-  getParamIds2(par.set$pars, repeated, with.nr)
+  UseMethod("getParamIds")
 }
 
-getParamIds2 = function(pars, repeated = FALSE, with.nr = FALSE) {
-  ns = lapply(pars, function(x) {
-    if (repeated && x$type %in% c(
-      "numericvector", "integervector", "discretevector",
-      "logicalvector", "charactervector")) {
-      n = x$len
-      if (n > 1 && with.nr)
-        paste(rep(x$id, n), 1:n, sep = "")
-      else
-        rep(x$id, n)
-    } else {
-      x$id
-    }
-  })
-  as.character(do.call(c, ns))
+#' @export
+getParamIds.ParamSet = function(par, repeated = FALSE, with.nr = FALSE) {
+  if (isEmpty(par))
+    return(character(0L))
+  unlist(lapply(par$pars, getParamIds, repeated = repeated, with.nr = with.nr), use.names = FALSE)
 }
 
+#' @export
+getParamIds.Param = function(par, repeated = FALSE, with.nr = FALSE) {
+  pid = par$id
+  if (repeated && isVector(par)) {
+    n = par$len
+    if (n > 1 && with.nr)
+      paste(rep(pid, n), 1:n, sep = "")
+    else
+      rep(pid, n)
+  } else {
+    pid
+  }
+}
